summaryrefslogtreecommitdiff
path: root/seckey.h
diff options
context:
space:
mode:
Diffstat (limited to 'seckey.h')
-rw-r--r--seckey.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/seckey.h b/seckey.h
index a918f75..35046a6 100644
--- a/seckey.h
+++ b/seckey.h
@@ -206,12 +206,13 @@ struct SymmetricCipherDocumentation
typedef SymmetricCipher Decryption;
};
-//! Authenticated encryption modes documentation.
-struct AuthenticatedSymmetricCipherDocumentation : public SymmetricCipherDocumentation
+/*! \brief Each class derived from this one defines two types, Encryption and Decryption,
+ both of which implement the AuthenticatedSymmetricCipher interface. */
+struct AuthenticatedSymmetricCipherDocumentation
{
//! implements the SymmetricCipher interface
typedef AuthenticatedSymmetricCipher Encryption;
//! implements the SymmetricCipher interface
typedef AuthenticatedSymmetricCipher Decryption;
};
@@ -206,12 +206,13 @@ struct SymmetricCipherDocumentation
{
- //! implements the SymmetricCipher interface
+ //! implements the AuthenticatedSymmetricCipher interface
typedef AuthenticatedSymmetricCipher Encryption;
@@ -206,12 +206,13 @@ struct SymmetricCipherDocumentation
typedef AuthenticatedSymmetricCipher Encryption;
- //! implements the SymmetricCipher interface
+ //! implements the AuthenticatedSymmetricCipher interface
typedef AuthenticatedSymmetricCipher Decryption;
};